@@ -1,5 +1,7 @@
 from clipboard.clipboard import Clipboard
 from clipboard.clipboard import ClipboardFormat
+from clipboard.clipboard import get_clipboard
+from clipboard.clipboard import set_clipboard
 from clipboard.html_clipboard import HTML_ENCODING
 from clipboard.html_clipboard import HTMLClipboard
 
@@ -9,4 +11,6 @@ __all__ = [
     "ClipboardFormat",
     "HTML_ENCODING",
     "HTMLClipboard",
+    "get_clipboard",
+    "set_clipboard",
 ]
